==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/eu.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Pribatutasuna",
    "-" : "-",
    "Your data is located in: " : "Zure datuak hemen daude:",
    "Please select a country" : "Mesedez aukeratu herrialde bat",
    "You don't have any shares with individual users." : "Ez duzu ezer elkarbanatuta banakako erabiltzaileren batekin.",
    "Somaliland" : "Somalilandia",
    "United Arab Emirates" : "Arabiar Emirerri Batuak",
    "Afghanistan" : "Afganistan",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegowina" : "Bosnia-Herzegovina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgika",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Brazil" : "Brasil",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorrusia",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Democratic Republic of the Congo" : "Kongoko Errepublika Demokratikoa",
    "Central African Republic" : "Afrika Erdiko Errepublika",
    "Congo" : "Kongoko Errepublika",
    "Switzerland" : "Suitza",
    "Cote d'Ivoire" : "Boli Kosta",
    "Chile" : "Txile",
    "Cameroon" : "Kamerun",
    "China" : "Txina",
    "Colombia" : "Kolombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cyprus" : "Zipre",
    "Czech" : "Txekia",
    "Germany" : "Alemania",
    "Denmark" : "Danimarka",
    "Dominican Republic" : "Dominikar Errepublika",
    "Ecuador" : "Ekuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egipto",
    "West Sahara" : "Mendebaldeko Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Espainia",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "France" : "Frantzia",
    "Gabon" : "Gabon",
    "United Kingdom" : "Erresuma Batua",
    "Georgia" : "Georgia",
    "Ghana" : "Ghana",
    "Gambia" : "Gambia",
    "Guinea" : "Ginea",
    "Equatorial Guinea" : "Ekuatore Ginea",
    "Greece" : "Grezia",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Ginea-Bissau",
    "Honduras" : "Honduras",
    "Croatia" : "Kroazia",
    "Hungary" : "Hungaria",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Islandia",
    "Italy" : "Itali",
    "Japan" : "Japonia",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgizistan",
    "Cambodia" : "Kanbodia",
    "North Korea" : "Ipar Korea",
    "South Korea" : "Hego Korea",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Kazakhstan",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxenburgo",
    "Morocco" : "Maroko",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagaskar",
    "Myanmar" : "Myanmar",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambike",
    "Namibia" : "Namibia",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Herbehereak",
    "Norway" : "Norvegia",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Pakistan" : "Pakistan",
    "Poland" : "Polonia",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguai",
    "Qatar" : "Qatar",
    "Romania" : "Errumania",
    "Serbia" : "Serbia",
    "Russia" : "Errusia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Slovenia" : "Eslovenia",
    "Slovakia" : "Eslovakia",
    "Sierra Leone" : "Sierra Leona",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "South Sudan" : "Hego Sudan",
    "El Salvador" : "El Salvador",
    "Syria" : "Syria",
    "Chad" : "Txad",
    "Tajikistan" : "Tajikistan",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Turkey" : "Turkia",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States" : "Ameriketako Estatu Batuak",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbekistan",
    "Venezuela" : "Venezuela",
    "Yemen" : "Yemen",
    "South Africa" : "Hegoafrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Control" : "Kontrola",
    "Knowledge" : "Ezagutza",
    "of how the data is stored" : "datuak nola dauden gordeta",
    "Freedom" : "Askatasuna",
    "to choose a platform" : "plataforma aukeratzea",
    "Learn more ↗" : "Ikasi gehiago ↗",
    "Administrators" : "Administratzaileak",
    "People you shared with" : "Pertsona hauekin elkarbanatu duzu"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/eu.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Pribatutasuna",
    "-" : "-",
    "Remove external admin" : "Kendu kanpo administratzailea",
    "Add external admin" : "Gehitu kanpo administratzailea",
    "Your files are not protected by encryption." : "Zure fitxategiak ez daude zifratze bidez babestuta",
    "This server is protected with full-disk-encryption." : "Zerbitzari hau disko osoko zifratzearekin babestuta dago",
    "This server is using full-disk-encryption." : "Zerbitzari hau disko osoko zifratzea ari da erabiltzen.",
    "Your data is located in: " : "Zure datuak hemen daude:",
    "Please select a country" : "Mesedez aukeratu herrialde bat",
    "You don't have any shares with individual users." : "Ez duzu ezer elkarbanatuta banakako erabiltzaileren batekin.",
    "Somaliland" : "Somalilandia",
    "United Arab Emirates" : "Arabiar Emirerri Batuak",
    "Afghanistan" : "Afganistan",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegowina" : "Bosnia-Herzegovina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgika",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Brazil" : "Brasil",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorrusia",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Democratic Republic of the Congo" : "Kongoko Errepublika Demokratikoa",
    "Central African Republic" : "Afrika Erdiko Errepublika",
    "Congo" : "Kongoko Errepublika",
    "Switzerland" : "Suitza",
    "Cote d'Ivoire" : "Boli Kosta",
    "Chile" : "Txile",
    "Cameroon" : "Kamerun",
    "China" : "Txina",
    "Colombia" : "Kolombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cyprus" : "Zipre",
    "Czech" : "Txekia",
    "Germany" : "Alemania",
    "Denmark" : "Danimarka",
    "Dominican Republic" : "Dominikar Errepublika",
    "Ecuador" : "Ekuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egipto",
    "West Sahara" : "Mendebaldeko Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Espainia",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "France" : "Frantzia",
    "Gabon" : "Gabon",
    "United Kingdom" : "Erresuma Batua",
    "Georgia" : "Georgia",
    "Ghana" : "Ghana",
    "Gambia" : "Gambia",
    "Guinea" : "Ginea",
    "Equatorial Guinea" : "Ekuatore Ginea",
    "Greece" : "Grezia",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Ginea-Bissau",
    "Honduras" : "Honduras",
    "Croatia" : "Kroazia",
    "Hungary" : "Hungaria",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Islandia",
    "Italy" : "Itali",
    "Japan" : "Japonia",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgizistan",
    "Cambodia" : "Kanbodia",
    "North Korea" : "Ipar Korea",
    "South Korea" : "Hego Korea",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Kazakhstan",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxenburgo",
    "Morocco" : "Maroko",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagaskar",
    "Myanmar" : "Myanmar",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambike",
    "Namibia" : "Namibia",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Herbehereak",
    "Norway" : "Norvegia",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Pakistan" : "Pakistan",
    "Poland" : "Polonia",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguai",
    "Qatar" : "Qatar",
    "Romania" : "Errumania",
    "Serbia" : "Serbia",
    "Russia" : "Errusia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Slovenia" : "Eslovenia",
    "Slovakia" : "Eslovakia",
    "Sierra Leone" : "Sierra Leona",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "South Sudan" : "Hego Sudan",
    "El Salvador" : "El Salvador",
    "Syria" : "Syria",
    "Chad" : "Txad",
    "Tajikistan" : "Tajikistan",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Turkey" : "Turkia",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States" : "Ameriketako Estatu Batuak",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbekistan",
    "Venezuela" : "Venezuela",
    "Yemen" : "Yemen",
    "South Africa" : "Hegoafrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Zure Nextcloud kontua",
    "Control" : "Kontrola",
    "Knowledge" : "Ezagutza",
    "of how the data is stored" : "datuak nola dauden gordeta",
    "Freedom" : "Askatasuna",
    "to choose a platform" : "plataforma aukeratzea",
    "Learn more ↗" : "Ikasi gehiago ↗",
    "Administrators" : "Administratzaileak",
    "People you shared with" : "Pertsona hauekin elkarbanatu duzu",
    "Privacy policy" : "Pribatutasun politika",
    "Read the privacy policy." : "Irakurri pribatutasun politika",
    "Encryption" : "Zifratzea"
},
"nplurals=2; plural=(n != 1);");
